@@ -33,36 +33,23 @@ class DummyAndroidLocalizer : public QObject
     Q_OBJECT
 
 public:
-    explicit DummyAndroidLocalizer(QObject *parent = 0)
-        : QObject(parent)
-    {
-    }
+    explicit DummyAndroidLocalizer(QObject *parent = 0) : QObject(parent) {}
 
-    Q_INVOKABLE QString i18n(const QString &message,
-                             const QVariant &p1 = QVariant(),
-                             const QVariant &p2 = QVariant(),
-                             const QVariant &p3 = QVariant(),
-                             const QVariant &p4 = QVariant(),
-                             const QVariant &p5 = QVariant(),
-                             const QVariant &p6 = QVariant(),
-                             const QVariant &p7 = QVariant(),
-                             const QVariant &p8 = QVariant(),
-                             const QVariant &p9 = QVariant(),
+    Q_INVOKABLE QString i18n(const QString &message, const QVariant &p1 = QVariant(),
+                             const QVariant &p2 = QVariant(), const QVariant &p3 = QVariant(),
+                             const QVariant &p4 = QVariant(), const QVariant &p5 = QVariant(),
+                             const QVariant &p6 = QVariant(), const QVariant &p7 = QVariant(),
+                             const QVariant &p8 = QVariant(), const QVariant &p9 = QVariant(),
                              const QVariant &p10 = QVariant()) const
     {
         return message;
     }
 
-    Q_INVOKABLE QString i18nc(const QString &context,
-                              const QString &message,
-                              const QVariant &p1 = QVariant(),
-                              const QVariant &p2 = QVariant(),
-                              const QVariant &p3 = QVariant(),
-                              const QVariant &p4 = QVariant(),
-                              const QVariant &p5 = QVariant(),
-                              const QVariant &p6 = QVariant(),
-                              const QVariant &p7 = QVariant(),
-                              const QVariant &p8 = QVariant(),
+    Q_INVOKABLE QString i18nc(const QString &context, const QString &message,
+                              const QVariant &p1 = QVariant(), const QVariant &p2 = QVariant(),
+                              const QVariant &p3 = QVariant(), const QVariant &p4 = QVariant(),
+                              const QVariant &p5 = QVariant(), const QVariant &p6 = QVariant(),
+                              const QVariant &p7 = QVariant(), const QVariant &p8 = QVariant(),
                               const QVariant &p9 = QVariant(),
                               const QVariant &p10 = QVariant()) const
     {
@@ -81,7 +68,7 @@ class UiController : public IUiController
 
 public:
     explicit UiController(QObject *parent = 0);
-    ~UiController() override;
+    ~UiController() override = default;
 
     bool initialize(Core *core);
     virtual QString errorString() const override;
